"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var card_1 = require("../src/card");
var shapes_1 = require("../src/shapes");
describe("Card", function () {
    it("should have a score", function () {
        var circle = (0, card_1.GetCircle)({
            value: 1,
        });
        chai_1.assert.equal(circle.score, 1);
    });
    describe("Star", function () {
        it("should have a double score", function () {
            var star = (0, card_1.GetStar)({
                value: 1,
            });
            chai_1.assert.equal(star.score, 2);
        });
    });
    describe(".matches()", function () {
        it("should be false if cards have different shapes", function () {
            chai_1.assert.isFalse((0, card_1.GetSquare)({ value: 1 }).matches((0, card_1.GetCircle)({ value: 8 })));
        });
        it("should be true if cards have different shapes but same value", function () {
            chai_1.assert.isTrue((0, card_1.GetSquare)({ value: 1 }).matches((0, card_1.GetCircle)({ value: 1 })));
        });
        it("should be true if cards have same shape but different values", function () {
            chai_1.assert.isTrue((0, card_1.GetCircle)({ value: 1 }).matches((0, card_1.GetCircle)({ value: 8 })));
        });
        it("should be true if cards have same shape and same values", function () {
            chai_1.assert.isTrue((0, card_1.GetCircle)({ value: 1 }).matches((0, card_1.GetCircle)({ value: 1 })));
        });
        it("should be true if either card is whot", function () {
            chai_1.assert.isTrue((0, card_1.GetCircle)({ value: 1 }).matches((0, card_1.GetWhot)({ iNeed: shapes_1.default.Circle, value: 20 })));
            chai_1.assert.isTrue((0, card_1.GetWhot)({ iNeed: shapes_1.default.Square, value: 20 }).matches((0, card_1.GetSquare)({ value: 2 })));
        });
        it("should NOT match because whot card has no value", function () {
            chai_1.assert.isFalse((0, card_1.GetWhot)({ value: 20 }).matches((0, card_1.GetSquare)({ value: 13 })));
        });
        it("should match because whot card needs a Square", function () {
            chai_1.assert.isTrue((0, card_1.GetWhot)({ iNeed: shapes_1.default.Square, value: 20 }).matches((0, card_1.GetSquare)({ value: 13 })));
        });
    });
});
//# sourceMappingURL=card.test.js.map