"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var events_1 = require("../src/events");
var events_2 = require("../src/events");
var chai_1 = require("chai");
describe('Eventify', function () {
    it('should have appropriate functions', function () {
        var target = (0, events_1.eventify)({});
        chai_1.assert.isFunction(target.once);
        chai_1.assert.isFunction(target.on);
        chai_1.assert.isFunction(target.removeListener);
        chai_1.assert.isFunction(target.emit);
    });
    describe('.on()', function () {
        it('should create an array in events', function () {
            var _a, _b;
            var target = (0, events_1.eventify)({});
            (_a = target.on) === null || _a === void 0 ? void 0 : _a.call(target, 'custom:name', function () { return ({}); });
            chai_1.assert.isArray((_b = target.events) === null || _b === void 0 ? void 0 : _b['custom:name']);
        });
        it('should add to array in events', function () {
            var _a, _b, _c;
            var target = (0, events_1.eventify)({});
            (_a = target.on) === null || _a === void 0 ? void 0 : _a.call(target, 'custom:name', function () { return ({}); });
            (_b = target.on) === null || _b === void 0 ? void 0 : _b.call(target, 'custom:name', function () { return ({}); });
            chai_1.assert.equal((_c = target.events) === null || _c === void 0 ? void 0 : _c['custom:name'].length, 2);
        });
    });
    describe('.emit()', function () {
        var value = false;
        it('should change value to true', function () {
            var _a, _b;
            var target = (0, events_1.eventify)({});
            (_a = target.on) === null || _a === void 0 ? void 0 : _a.call(target, 'value:toggle', function () {
                value = true;
            });
            (_b = target.emit) === null || _b === void 0 ? void 0 : _b.call(target, 'value:toggle', null);
            chai_1.assert.isTrue(value);
        });
    });
    describe('.removeListener()', function () {
        it('should have event count as zero', function () {
            var _a, _b, _c, _d;
            var target = (0, events_1.eventify)({});
            var listener = function () { return ({}); };
            (_a = target.on) === null || _a === void 0 ? void 0 : _a.call(target, 'custom:name', listener);
            chai_1.assert.equal((_b = target.events) === null || _b === void 0 ? void 0 : _b['custom:name'].length, 1);
            (_c = target.removeListener) === null || _c === void 0 ? void 0 : _c.call(target, 'custom:name', listener);
            chai_1.assert.equal((_d = target.events) === null || _d === void 0 ? void 0 : _d['custom:name'].length, 0);
        });
    });
    describe('.once()', function () {
        it('should always have events count as 1', function () {
            var _a, _b, _c, _d;
            var target = (0, events_1.eventify)({});
            var listener = function () { return ({}); };
            (_a = target.once) === null || _a === void 0 ? void 0 : _a.call(target, 'custom:name', listener);
            chai_1.assert.equal((_b = target.events) === null || _b === void 0 ? void 0 : _b['custom:name'].length, 1);
            (_c = target.emit) === null || _c === void 0 ? void 0 : _c.call(target, 'custom:name', null);
            chai_1.assert.equal((_d = target.events) === null || _d === void 0 ? void 0 : _d['custom:name'].length, 0);
        });
    });
});
describe('RaiseEvents', function () {
    var value = false;
    it('should change value to true', function () {
        events_2.default.on('value:toggle', function () {
            value = true;
        });
        (0, events_1.raiseEvent)('value:toggle');
        chai_1.assert.isTrue(value);
    });
});
//# sourceMappingURL=events.test.js.map