"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var shapes_1 = require("../src/shapes");
var src_1 = require("../src");
var logger_1 = require("../src/logger");
var card_1 = require("../src/card");
var logger = (0, logger_1.default)("index.test.js");
var makeRandomPlay = function (player, game) {
    if (player.canPlay()) {
        var compatibles = player
            .hand()
            .filter(function (card) { return card.matches(game.pile.top()); });
        var compatibleCardIndex = player
            .hand()
            .indexOf(compatibles[Math.floor(Math.random() * compatibles.length)]);
        var iNeed = undefined;
        if (player.hand()[compatibleCardIndex].shape === shapes_1.default.Whot) {
            var eligibleCards = player
                .hand()
                .filter(function (card) { return card.shape != shapes_1.default.Whot; });
            iNeed =
                (eligibleCards[Math.floor(Math.random() * eligibleCards.length)] || {})
                    .shape || shapes_1.default.Circle;
        }
        player.play(compatibleCardIndex, iNeed);
        game.turn.execute(game.pile.top());
    }
    else {
        var marketCards = player.pick();
        game.turn.switch();
    }
};
describe("Game", function () {
    describe("Constructor", function () {
        it("should throw InvalidArgumentTypeError", function () {
            try {
                var game = new src_1.default({
                    noOfDecks: 1,
                    // @ts-ignore
                    noOfPlayers: null
                });
            }
            catch (err) {
                chai_1.assert.equal(err.name, "InvalidArgumentTypeError");
                chai_1.assert.equal(err.message, "props.noOfPlayers");
            }
        });
        it("should work", function () {
            var _a, _b, _c;
            var game = new src_1.default({
                noOfDecks: 2,
                noOfPlayers: 4,
            });
            var endGame = false;
            game.emitter.on("player:play", function (player, card) {
                logger.log(player.render(), "| old:", game.pile.top().render(), "| play:", card.render());
            });
            game.emitter.on("player:market", function (player, marketCards) {
                logger.warn(player.render(), "| old:", game.pile.top().render(), "| market:", marketCards.map(function (card) { return card.render(); }).join(", "));
            });
            logger.warn("Game Start: top:", game.pile.top().render(), " | ", (_b = (_a = game.turn) === null || _a === void 0 ? void 0 : _a.next()) === null || _b === void 0 ? void 0 : _b.render());
            for (var i = 1; i <= 50; i++) {
                if (!endGame) {
                    var nextPlay = (_c = game.turn) === null || _c === void 0 ? void 0 : _c.next();
                    if (!nextPlay) {
                        throw new Error("nextPlay cannot be undefined");
                    }
                    makeRandomPlay(nextPlay, game);
                }
            }
        });
        it("should have Whot! as its first card", function () {
            var game = new src_1.default({
                noOfDecks: 1,
                noOfPlayers: 2,
                firstCard: (0, card_1.GetWhot)({
                    value: 20
                }),
            });
            chai_1.assert.equal(game.pile.top().shape, shapes_1.default.Whot);
        });
        it("should play !Whot card when whot card is first in the pile", function () {
            var game = new src_1.default({
                noOfDecks: 1,
                noOfPlayers: 2,
                firstCard: (0, card_1.GetWhot)({
                    value: 20
                }),
            });
            var player = game.turn.next();
            while (!(player === null || player === void 0 ? void 0 : player.canPlay())) {
                var marketCards = player === null || player === void 0 ? void 0 : player.pick();
                game.turn.switch();
                player = game.turn.next();
            }
            var compatibleCardIndex = player
                .hand()
                .findIndex(function (card) { return shapes_1.default.Whot !== card.shape; });
            var card = player.hand()[compatibleCardIndex];
            chai_1.assert.notEqual(card.shape, shapes_1.default.Whot);
            player.play(compatibleCardIndex);
        });
    });
});
//# sourceMappingURL=index.test.js.map