"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var events_1 = require("../src/events");
var pile_1 = require("../src/pile");
var market_1 = require("../src/market");
describe("Market", function () {
    describe("Constructor", function () {
        it("should have cards length = noOfDecks * 54", function () {
            var market = new market_1.default({
                noOfDecks: 1,
                emitter: events_1.default,
                pile: function () { return new pile_1.default({ emitter: events_1.default }); },
            });
            chai_1.assert.equal(market.count(), 54);
            var market2 = new market_1.default({
                noOfDecks: 2,
                emitter: events_1.default,
                pile: function () { return new pile_1.default({ emitter: events_1.default }); },
            });
            chai_1.assert.equal(market2.count(), 108);
        });
    });
    describe("Pick(n)", function () {
        it("should remove (n) cards from the market", function () {
            var market = new market_1.default({
                noOfDecks: 1,
                emitter: events_1.default,
                pile: function () { return new pile_1.default({ emitter: events_1.default }); },
            });
            var pickedCards = market.pick(2);
            chai_1.assert.equal(pickedCards.length, 2);
            chai_1.assert.equal(market.count(), 52);
        });
        it("should throw PropNotFoundError because pile() not provided", function () {
            try {
                // @ts-ignore
                var market = new market_1.default({ noOfDecks: 1, emitter: events_1.default, pile: null });
                market.pick(55);
                chai_1.assert.fail();
            }
            catch (err) {
                chai_1.assert.equal(err.name, "PropNotFoundError");
            }
        });
        it("should throw OutOfRangeError if (n) >= .count*()", function () {
            try {
                var pile = function () { return new pile_1.default({ emitter: events_1.default }); };
                var market = new market_1.default({ noOfDecks: 1, emitter: events_1.default, pile: pile });
                var pickedCards = market.pick(55);
                chai_1.assert.fail();
            }
            catch (err) {
                chai_1.assert.equal(err.name, "OutOfRangeError");
            }
        });
    });
});
//# sourceMappingURL=market.test.js.map