"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var card_1 = require("../src/card");
var events_1 = require("../src/events");
var pile_1 = require("../src/pile");
describe("Pile", function () {
    describe(".top()", function () {
        it("should be null initially", function () {
            var pile = new pile_1.default({ emitter: events_1.default });
            chai_1.assert.isNull(pile.top());
        });
    });
    describe(".push([...])", function () {
        it("should throw InvalidArgumentTypeError(Array)", function () {
            try {
                var pile = new pile_1.default({ emitter: events_1.default });
                // @ts-ignore
                pile.push({});
                chai_1.assert.fail();
            }
            catch (err) {
                chai_1.assert.equal(err.name, "InvalidArgumentTypeError");
                chai_1.assert.equal(err.type.name, "Array");
            }
        });
        it("should throw NoCardSuppliedError when _cards_[] is empty", function () {
            try {
                var pile = new pile_1.default({ emitter: events_1.default });
                pile.push([]);
                chai_1.assert.fail();
            }
            catch (err) {
                chai_1.assert.equal(err.name, "NoCardSuppliedError");
            }
        });
        it("should throw LastCardMismatchError", function () {
            try {
                var pile = new pile_1.default({ emitter: events_1.default });
                var card = (0, card_1.GetCircle)({ value: 1 });
                var card2 = (0, card_1.GetSquare)({ value: 2 });
                pile.push([card]);
                pile.push([card2]);
                chai_1.assert.fail();
            }
            catch (err) {
                chai_1.assert.equal(err.name, "LastCardMismatchError");
            }
        });
        it("should work", function () {
            var pile = new pile_1.default({ emitter: events_1.default });
            var card = (0, card_1.GetCircle)({ value: 1 });
            pile.push([card]);
            chai_1.assert.deepEqual(pile.top(), card);
        });
    });
});
//# sourceMappingURL=pile.test.js.map