"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var turn_1 = require("../src/turn");
var player_1 = require("../src/player");
var market_1 = require("../src/market");
var pile_1 = require("../src/pile");
var events_1 = require("../src/events");
describe("Turn", function () {
    var pile = new pile_1.default({
        emitter: events_1.emitter,
    });
    var market = new market_1.default({ noOfDecks: 1, pile: function () { return pile; }, emitter: events_1.emitter });
    var player1 = new player_1.default({
        id: 1,
        emitter: new events_1.EventEmitter(),
        // @ts-ignore
        validator: function () { return true; },
        market: function () { return market; },
    });
    var player2 = new player_1.default({
        id: 2,
        emitter: new events_1.EventEmitter(),
        // @ts-ignore
        validator: function () { return true; },
        market: function () { return market; },
    });
    var player3 = new player_1.default({
        id: 3,
        emitter: new events_1.EventEmitter(),
        // @ts-ignore
        validator: function () { return true; },
        market: function () { return market; },
    });
    var players = [player1, player2, player3];
    describe("Constructor", function () {
        it("should throw InvalidArgumentTypeError if _player_ is not Array", function () {
            try {
                // @ts-ignore
                var turn = new turn_1.default({
                    emitter: events_1.emitter,
                });
                chai_1.assert.fail();
            }
            catch (err) {
                chai_1.assert.equal(err.name, "InvalidArgumentTypeError");
            }
        });
        it("should create props emitter if NOT defined", function () {
            var props = {
                players: players,
                emitter: null
            };
            // @ts-ignore
            var turn = new turn_1.default(props);
            chai_1.assert.isDefined(props.emitter);
        });
        it("should throw PlayersNotEnoughError if props.players.length === 0", function () {
            try {
                var turn = new turn_1.default({
                    players: [],
                    emitter: new events_1.EventEmitter(),
                });
                chai_1.assert.fail();
            }
            catch (err) {
                chai_1.assert.equal(err.name, "PlayersNotEnoughError");
            }
        });
        it("should work", function () {
            var turn = new turn_1.default({
                players: [player1, player2, player3],
                emitter: new events_1.EventEmitter(),
            });
        });
    });
    describe(".next()", function () {
        var turn = new turn_1.default({
            players: [player1, player2, player3],
            emitter: new events_1.EventEmitter(),
        });
        it("should have a value which is equal to player1", function () {
            chai_1.assert.deepEqual(turn.next(), player1);
        });
    });
    describe(".switch(skip).next()", function () {
        it("should equal player2", function () {
            var turn = new turn_1.default({
                players: [player1, player2, player3],
                emitter: new events_1.EventEmitter(),
            });
            turn.switch();
            chai_1.assert.deepEqual(turn.next(), player2);
        });
        it("should equal player3", function () {
            var turn = new turn_1.default({
                players: [player1, player2, player3],
                emitter: new events_1.EventEmitter(),
            });
            turn.switch(1);
            chai_1.assert.deepEqual(turn.next(), player3);
        });
    });
    describe(".setToPick(n, count)", function () {
        it("should have player2.toPick === 2", function () {
            var turn = new turn_1.default({
                players: [player1, player2, player3],
                emitter: new events_1.EventEmitter(),
            });
            turn.setToPick(1, 2);
            chai_1.assert.equal(player1.toPick, 0);
            chai_1.assert.equal(player2.toPick, 2);
            chai_1.assert.equal(player3.toPick, 0);
        });
        it("should have && player2.toPick === 1 && player3.toPick === 1", function () {
            var turn = new turn_1.default({
                players: [player1, player2, player3],
                emitter: new events_1.EventEmitter(),
            });
            turn.setToPick(2, 1);
            chai_1.assert.equal(player1.toPick, 0);
            chai_1.assert.equal(player2.toPick, 1);
            chai_1.assert.equal(player3.toPick, 1);
        });
    });
    describe(".holdon()", function () {
        it("should make the same player the value of .next()", function () {
            var turn = new turn_1.default({
                players: [player1, player2, player3],
                emitter: new events_1.EventEmitter(),
            });
            turn.holdon();
            chai_1.assert.deepEqual(turn.next(), player1);
        });
    });
    describe(".pickTwo()", function () {
        it("should have player2.toPick === 2", function () {
            var turn = new turn_1.default({
                players: [player1, player2, player3],
                emitter: new events_1.EventEmitter(),
            });
            turn.pickTwo();
            chai_1.assert.equal(player2.toPick, 2);
        });
        describe("defer", function () {
            it("should have player3.toPick === 4", function () {
                var turn = new turn_1.default({
                    players: [player1, player2, player3],
                    emitter: new events_1.EventEmitter(),
                });
                turn.pickTwo();
                turn.pickTwo();
                chai_1.assert.equal(player1.toPick, 0);
                chai_1.assert.equal(player2.toPick, 0);
                chai_1.assert.equal(player3.toPick, 4);
            });
            describe(".pickTwo().switch().pickThree()", function () {
                it("should throw InappropriateMoveError", function () {
                    try {
                        var turn = new turn_1.default({
                            players: [player1, player2, player3],
                            emitter: new events_1.EventEmitter(),
                        });
                        turn.pickTwo();
                        turn.pickThree();
                        chai_1.assert.fail();
                    }
                    catch (err) {
                        chai_1.assert.equal(err.name, "InappropriateMoveError");
                        chai_1.assert.equal(err.message, "pickThree");
                    }
                });
            });
        });
        describe(".pickThree()", function () {
            it("should have .next().toPick === 3", function () {
                var turn = new turn_1.default({
                    players: [player1, player2, player3],
                    emitter: new events_1.EventEmitter(),
                });
                turn.pickThree();
                chai_1.assert.equal(player2.toPick, 3);
            });
            describe("defer", function () {
                it("should have player3.toPick === 6", function () {
                    var turn = new turn_1.default({
                        players: [player1, player2, player3],
                        emitter: new events_1.EventEmitter(),
                    });
                    turn.pickThree();
                    turn.pickThree();
                    chai_1.assert.equal(player1.toPick, 0);
                    chai_1.assert.equal(player2.toPick, 0);
                    chai_1.assert.equal(player3.toPick, 6);
                });
                describe(".pickThree().switch().pickTwo()", function () {
                    it("should throw InappropriateMoveError", function () {
                        try {
                            var turn = new turn_1.default({
                                players: [player1, player2, player3],
                                emitter: new events_1.EventEmitter(),
                            });
                            turn.pickThree();
                            turn.pickTwo();
                            chai_1.assert.fail();
                        }
                        catch (err) {
                            chai_1.assert.equal(err.name, "InappropriateMoveError");
                            chai_1.assert.equal(err.message, "pickTwo");
                        }
                    });
                });
            });
        });
        describe(".suspension()", function () {
            it("should have .next() === player3", function () {
                var turn = new turn_1.default({
                    players: [player1, player2, player3],
                    emitter: new events_1.EventEmitter(),
                });
                turn.suspension();
                chai_1.assert.deepEqual(turn.next(), player3);
            });
            describe("isStar = true", function () {
                it("should have .next() === player1", function () {
                    var turn = new turn_1.default({
                        players: [player1, player2, player3],
                        emitter: new events_1.EventEmitter(),
                    });
                    turn.suspension(true);
                    chai_1.assert.deepEqual(turn.next(), player1);
                });
            });
        });
        describe(".count()", function () {
            it("should be 3", function () {
                var turn = new turn_1.default({
                    players: [player1, player2, player3],
                    emitter: new events_1.EventEmitter(),
                });
                chai_1.assert.equal(turn.count(), 3);
            });
        });
        describe(".all(fn)", function () {
            it("should be 3", function () {
                var turn = new turn_1.default({
                    players: [player1, player2, player3],
                    emitter: new events_1.EventEmitter(),
                });
                chai_1.assert.equal(turn.all(), 3);
            });
        });
    });
});
//# sourceMappingURL=turn.test.js.map